@@ -16,7 +16,7 @@ try:
             try:
                 self._repo = HG.repository(ui.ui(), path=self.path or '.')
                 self._revision = self._repo[len(self._repo) - 1].hex()
-                self._tag = self._repo.tagslist()[0]
+                self._tag = self._repo.tagslist()[0][1]
             except error.RepoError:
                 message = 'Mercurial repository not found: {0}'.format(
                     self.path)
